package com.bonus.canteen.core.supermarket.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.supermarket.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.supermarket.domain.SupermarketMaterial;
import com.bonus.canteen.core.supermarket.service.ISupermarketMaterialService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 商品信息Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "商品信息接口")
@RestController
@RequestMapping("/supermarket_material")
public class SupermarketMaterialController extends BaseController {
    @Autowired
    private ISupermarketMaterialService supermarketMaterialService;

    /**
     * 查询商品信息列表
     */
    @ApiOperation(value = "查询商品信息列表")
    //@RequiresPermissions("supermarket:material:list")
    @GetMapping("/list")
    public TableDataInfo list(SupermarketMaterial supermarketMaterial) {
        startPage();
        List<SupermarketMaterial> list = supermarketMaterialService.selectSupermarketMaterialList(supermarketMaterial);
        return getDataTable(list);
    }

    /**
     * 导出商品信息列表
     */
    @ApiOperation(value = "导出商品信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:material:export")
    @SysLog(title = "商品信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出商品信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SupermarketMaterial supermarketMaterial) {
        List<SupermarketMaterial> list = supermarketMaterialService.selectSupermarketMaterialList(supermarketMaterial);
        ExcelUtil<SupermarketMaterial> util = new ExcelUtil<SupermarketMaterial>(SupermarketMaterial.class);
        util.exportExcel(response, list, "商品信息数据");
    }

    /**
     * 获取商品信息详细信息
     */
    @ApiOperation(value = "获取商品信息详细信息")
    //@RequiresPermissions("supermarket:material:query")
    @GetMapping(value = "/{materialId}")
    public AjaxResult getInfo(@PathVariable("materialId") Long materialId) {
        return success(supermarketMaterialService.selectSupermarketMaterialByMaterialId(materialId));
    }

    /**
     * 新增商品信息
     */
    @ApiOperation(value = "新增商品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:material:add")
    @SysLog(title = "商品信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增商品信息")
    @PostMapping
    public AjaxResult add(@RequestBody SupermarketMaterial supermarketMaterial) {
        try {
            return toAjax(supermarketMaterialService.insertSupermarketMaterial(supermarketMaterial));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改商品信息
     */
    @ApiOperation(value = "修改商品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:material:edit")
    @SysLog(title = "商品信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改商品信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody SupermarketMaterial supermarketMaterial) {
        try {
            return toAjax(supermarketMaterialService.updateSupermarketMaterial(supermarketMaterial));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除商品信息
     */
    @ApiOperation(value = "删除商品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:material:remove")
    @SysLog(title = "商品信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除商品信息")
	@PostMapping("/del/{materialIds}")
    public AjaxResult remove(@PathVariable Long[] materialIds) {
        return toAjax(supermarketMaterialService.deleteSupermarketMaterialByMaterialIds(materialIds));
    }
}
